@@ -1,12 +1,12 @@
 ;;; greader.el --- gnamù reader, send buffer contents to a speech engine. -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2017-2023  Free Software Foundation, Inc.
+;; Copyright (C) 2017-2024  Free Software Foundation, Inc.
 
 ;; package-requires: ((emacs "25"))
 ;; Author: Michelangelo Rodriguez <michelangelo.rodriguez@gmail.com>
 ;; Keywords: tools, accessibility
 
-;; Version: 0.8.0
+;; Version: 0.8.2
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -82,8 +82,8 @@ Return SENTENCE, eventually modified by the functions."
     (run-hook-wrapped 'greader-after-get-sentence-functions
                       (lambda (func)
                         (when (fboundp func)
-	                  (setq result (or (funcall func result)
-	                                   sentence)))))
+	                  (setq result (funcall func result))
+			  nil)))
     result))
 
 (defvar greader-before-read-hook nil
@@ -1490,14 +1490,15 @@ If it is a function, it must return a string."
 	;; Update the search position taking into account the "link: " string we just entered.
         (setq pos (+ pos 6))))
     ;; Return the modified string if links were found.
-    (if modified result nil)))
+    (if modified result input-string)))
 
 ;;;###autoload
 (define-minor-mode greader-enriched-mode
   "This mode causes greader to announce clickable objects.
 To configure the message with which it must be announced
 the element, configure the `greader-enriched-tag' variable."
-  :lighter "rich"
+  :lighter " rich"
+  :global t
   (if greader-enriched-mode
       (progn
 	(unless greader-mode
